import React, { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import axios from "axios";
import styles from "./UserSearchResults.module.css";

const UserSearchResults = () => {
  const { personId } = useParams();
  const [personInfo, setPersonInfo] = useState(null);
  const [degrees, setDegrees] = useState([]);
  const [involvements, setInvolvements] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchPersonDetails = async () => {
      setLoading(true);
      setError(null);

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${personId}`
        );

        const { personInfo, degrees, involvements } = response.data.person;

        setPersonInfo(personInfo);
        setDegrees(degrees);
        setInvolvements(involvements);
      } catch (err) {
        setError(err.response?.data?.message || "Failed to fetch user details.");
      } finally {
        setLoading(false);
      }
    };

    fetchPersonDetails();
  }, [personId]);

  if (loading) return <p>Loading user details...</p>;
  if (error) return <p className={styles.error}>{error}</p>;

  return (
    <div className={styles.container}>
      <h2>User Details</h2>
      <div>
        <h3>Personal Information</h3>
        {Object.entries(personInfo || {}).map(([key, value]) =>
          key.toLowerCase().includes("id") ? null : (
            <p key={key}>
              <strong>{key.replace(/([A-Z])/g, " $1")}:</strong> {value || "N/A"}
            </p>
          )
        )}
      </div>

      <div>
        <h3>Degrees</h3>
        {degrees.map((degree, index) => (
          <div key={index} className={styles.listItem}>
            {Object.entries(degree).map(([key, value]) =>
              key.toLowerCase().includes("id") ? null : (
                <p key={key}>
                  <strong>{key.replace(/([A-Z])/g, " $1")}:</strong> {value || "N/A"}
                </p>
              )
            )}
          </div>
        ))}
      </div>

      <div>
        <h3>Involvements</h3>
        {involvements.map((involvement, index) => (
          <div key={index} className={styles.listItem}>
            <p>{involvement || "N/A"}</p>
          </div>
        ))}
      </div>
    </div>
  );
};

export default UserSearchResults;
